@@ -17,10 +17,13 @@ def extract_postcode_from_address_series(s: pandas.Series) -> tuple[str, str]:
   return pandas.Series(extract_postcode_from_address(s['address_1'], False))
 
 def extract_full_name(full_name: str) -> tuple[str, str]:
-  parts = full_name.strip().split()
+  full_name = full_name.strip()
+  pattern = re.compile(r"^(Mrs|Mr|Ms|Miss|Dr)\.?\s*", re.IGNORECASE)
+  full_name = re.sub(pattern, "", full_name)
+  parts = full_name.split()
   first_name = parts[0]
-  last_name = ' '.join(parts[1:]).strip()
-  if last_name == '': last_name = None
+  last_name = parts[len(parts)-1].strip()
+  if last_name == '' or len(parts) == 1: last_name = None
   return first_name, last_name
 
 def extract_full_name_from_series(s: pandas.Series, key: str) -> tuple[str, str]:
